==> lxqt-notificationd_0.14.1.orig.tar.xz: lxqt-notificationd-0.14.1/config/translations/lxqt-config-notificationd_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Medidas</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="32"/>
        <location filename="../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Espaciado:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Algunas notificaciones establecen su propia duración en pantalla.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Duración por defecto:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="127"/>
        <source>Unattended Notifications</source>
        <translation>Notificaciones desatendidas</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>How many to save:</source>
        <translation>Cuántas se guardan:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <location filename="../advancedsettings.ui" line="159"/>
        <source>Application name is on the top of notification.</source>
        <translation>El nombre de la aplicación está en la parte superior de la notificación.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="152"/>
        <source>Ignore these applications:</source>
        <translation>Ignorar estas aplicaciones:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="162"/>
        <source>app1,app2,app3</source>
        <translation>aplicación1,aplicación2,aplicación3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Configuración básica</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Posición en la pantalla</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="56"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Aviso:&lt;/b&gt; no hay ningún demonio de notificaciones en ejecución.
Se usará un medio alternativo.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="59"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Aviso:&lt;/b&gt; un demonio de notificaciones de terceros (%1) está en ejecución.
¡Estos ajustes no tendrán ningún efecto sobre él!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="112"/>
        <source>Notification demo </source>
        <translation>Prueba de notificación </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="113"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Esto es una notificación de prueba
 Todas las notificaciones aparecerán desde ahora aquí en LXQt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Notificaciones del escritorio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>Configuración básica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>Configuración avanzada</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_0.16.0.orig.tar.xz: lxqt-notificationd-0.16.0/config/translations/lxqt-config-notificationd_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>Medidas</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>Espaciado:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Algunas notificaciones establecen su propia duración en pantalla.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>Duración por defecto:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Notificaciones desatendidas</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Cuántas se guardan:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>El nombre de la aplicación está en la parte superior de la notificación.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>Ignorar estas aplicaciones:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>aplicación1,aplicación2,aplicación3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Configuración básica</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Posición en la pantalla</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="61"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="70"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Aviso:&lt;/b&gt; no hay ningún demonio de notificaciones en ejecución.
Se usará un medio alternativo.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="73"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Aviso:&lt;/b&gt; un demonio de notificaciones de terceros (%1) está en ejecución.
¡Estos ajustes no tendrán ningún efecto sobre él!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="131"/>
        <source>Notification demo </source>
        <translation>Prueba de notificación </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="132"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Esto es una notificación de prueba
 Todas las notificaciones aparecerán desde ahora aquí en LXQt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Notificaciones del escritorio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>Configuración básica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>Configuración avanzada</translation>
    </message>
</context>
</TS>
